import { Select } from 'antd';
import { SelectProps, SelectValue } from 'antd/lib/select';
import React from 'react';
export declare type OptionType = Record<string, string | number>;
export declare type ValueType = SelectValue | OptionType | OptionType[];
export declare type SelectType = SelectProps<ValueType>;
export declare type Props = Omit<Partial<SelectType>, 'defaultValue'> & {
    /**
     * Promise to fetch options
     */
    promiseFn: () => Promise<OptionType[]>;
    /**
     * Event handler triggered when selected option changes
     */
    onChange?: SelectProps<ValueType>['onChange'];
    /**
     * Selected option value
     */
    value?: ValueType;
    /**
     * Key to render `label` in option object
     */
    labelKey?: string;
    /**
     * Key to render `value` in option object
     */
    valueKey?: string;
    /**
     * If true, selected value contains original option object
     */
    optionInValue?: boolean;
    /**
     * If true, open select when select status is changed from `disabled` to `active`
     */
    focusIfActive?: boolean;
    /**
     * Select placeholder
     */
    placeholder?: string;
    /**
     * Select disabled
     */
    disabled?: boolean;
    /**
     * Allow to clear selected option
     */
    allowClear?: boolean;
    /**
     * Allow to search options
     */
    showSearch?: boolean;
    /**
     * Show select arrow
     */
    showArrow?: boolean;
    /**
     * Show select arrow (mode: 'multiple' | 'tags')
     */
    mode?: SelectType['mode'];
    /**
     * Key to filter options
     */
    optionFilterProp?: string;
    /**
     * Use display block style
     */
    block?: boolean;
};
declare const AntdAsyncSslect: React.ForwardRefExoticComponent<Pick<Partial<SelectType>, "mode" | "prefixCls" | "id" | "className" | "style" | "options" | "children" | "value" | "labelInValue" | "inputValue" | "searchValue" | "optionFilterProp" | "filterOption" | "showSearch" | "autoClearSearchValue" | "onSearch" | "onClear" | "allowClear" | "clearIcon" | "showArrow" | "removeIcon" | "menuItemSelectedIcon" | "open" | "defaultOpen" | "listHeight" | "listItemHeight" | "dropdownStyle" | "dropdownClassName" | "dropdownMatchSelectWidth" | "virtual" | "dropdownRender" | "dropdownAlign" | "animation" | "transitionName" | "getPopupContainer" | "direction" | "disabled" | "loading" | "autoFocus" | "defaultActiveFirstOption" | "notFoundContent" | "placeholder" | "optionLabelProp" | "maxTagTextLength" | "maxTagCount" | "maxTagPlaceholder" | "tokenSeparators" | "tagRender" | "showAction" | "tabIndex" | "onKeyUp" | "onKeyDown" | "onPopupScroll" | "onDropdownVisibleChange" | "onSelect" | "onDeselect" | "onInputKeyDown" | "onClick" | "onChange" | "onBlur" | "onFocus" | "onMouseDown" | "onMouseEnter" | "onMouseLeave" | "choiceTransitionName" | "internalProps" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "suffixIcon" | "size" | "bordered"> & {
    /**
     * Promise to fetch options
     */
    promiseFn: () => Promise<OptionType[]>;
    /**
     * Event handler triggered when selected option changes
     */
    onChange?: SelectProps<ValueType>['onChange'];
    /**
     * Selected option value
     */
    value?: string | number | Record<string, string | number> | (string | number)[] | import("antd/lib/select").LabeledValue | import("antd/lib/select").LabeledValue[] | Record<string, string | number>[] | undefined;
    /**
     * Key to render `label` in option object
     */
    labelKey?: string | undefined;
    /**
     * Key to render `value` in option object
     */
    valueKey?: string | undefined;
    /**
     * If true, selected value contains original option object
     */
    optionInValue?: boolean | undefined;
    /**
     * If true, open select when select status is changed from `disabled` to `active`
     */
    focusIfActive?: boolean | undefined;
    /**
     * Select placeholder
     */
    placeholder?: string | undefined;
    /**
     * Select disabled
     */
    disabled?: boolean | undefined;
    /**
     * Allow to clear selected option
     */
    allowClear?: boolean | undefined;
    /**
     * Allow to search options
     */
    showSearch?: boolean | undefined;
    /**
     * Show select arrow
     */
    showArrow?: boolean | undefined;
    /**
     * Show select arrow (mode: 'multiple' | 'tags')
     */
    mode?: SelectType['mode'];
    /**
     * Key to filter options
     */
    optionFilterProp?: string | undefined;
    /**
     * Use display block style
     */
    block?: boolean | undefined;
} & React.RefAttributes<Select<SelectValue>>>;
export default AntdAsyncSslect;
